package com.himajin2001.marubatsu.player;

import com.himajin2001.marubatsu.board.STONE;
import com.himajin2001.marubatsu.control.Position;

/**
 * 対戦者(Player)を表すInterface。
 * 
 * 対戦者はこのInterfaceを実装したclassを作成すること。
 * 
 * @author tsubasa
 */
public interface IPlayer {

	/**
	 * 盤面の幅を設定する。
	 * 
	 * ゲーム側よりゲーム開始前にセットされる。<br>
	 * 実装側で呼び出してはいけない。<br>
	 * 
	 * @param width
	 *            盤面の幅。
	 */
	public void setWidth(final int width);

	/**
	 * 盤面の高さを設定する。
	 * 
	 * ゲーム側よりゲーム開始前にセットされる。<br>
	 * 実装側で呼び出してはいけない。<br>
	 * 
	 * @param hight
	 *            盤面の幅。
	 */
	public void setHight(final int hight);

	/**
	 * 自分の石の色を設定する。
	 * 
	 * ゲーム側よりゲーム開始前にセットされる。<br>
	 * 実装側で呼び出してはいけない。<br>
	 * 
	 * @param stone
	 *            自分の担当の石の色。({@link STONE#BLANK}だったら先攻。)
	 */
	public void setStone(final STONE stone);

	/**
	 * 盤面の状態を判断して石を置く。
	 * 
	 * @param hexes
	 *            現在の盤面に置かれた石のスナップショット。
	 * @return 判断の結果石を置く座標。
	 * @throws Exception
	 *             ギブアップと見なす。(頑張ってException出ないようにしてね！(笑))
	 */
	public Position think(final STONE[][] hexes) throws Exception;

	/**
	 * 対戦者の名前を取得する。
	 * 
	 * ゲームが始まる前や始まった後にゲーム側から呼ばれる。<br>
	 * nullではないこと。(nullだと即時反則負けになる。)
	 * 
	 * @return 対戦者の名前。(思考ルーチンの名前)
	 */
	public String getName();
}
